@@ -15,6 +15,7 @@
 class QMenu;
 
 /**
+ * @internal
  * Date selection table.
  * This is a support class for the KDatePicker class.  It just
  * draws the calendar table without titles, but could theoretically
@@ -25,7 +26,6 @@ class QMenu;
  *
  * \image html kdatetable.png "KDE Date Selection Table"
  *
- * @internal
  * @author Tim Gilman, Mirko Boehm
  */
 class KDateTable : public QWidget
@@ -93,8 +93,7 @@ public:
      * Makes a given date be painted with a given foregroundColor, and background
      * (a rectangle, or a circle/ellipse) in a given color.
      */
-    void setCustomDatePainting(const QDate &date, const QColor &fgColor,
-                               BackgroundMode bgMode = NoBgMode, const QColor &bgColor = QColor());
+    void setCustomDatePainting(const QDate &date, const QColor &fgColor, BackgroundMode bgMode = NoBgMode, const QColor &bgColor = QColor());
 
     /**
      * Unsets the custom painting of a date so that the date is painted as usual.
@@ -136,14 +135,6 @@ Q_SIGNALS:
      */
     void dateChanged(const QDate &date);
 
-    /**
-     * This function behaves essentially like the one above.
-     * The selected date changed.
-     * @param cur The current date
-     * @param old The date before the date was changed
-     */
-    void dateChanged(const QDate &cur, const QDate &old);
-
     /**
      * A date has been selected by clicking on the table.
      */
