@@ -15,70 +15,57 @@
 */
 
 #include "ktoggleaction.h"
-
-#include <kguiitem.h>
-
-class Q_DECL_HIDDEN KToggleAction::Private
-{
-public:
-    Private(KToggleAction *_parent)
-        : parent(_parent)
-    {
-    }
-
-    ~Private()
-    {
-        delete checkedGuiItem;
-    }
-
-    void init()
-    {
-        parent->setCheckable(true);
-        connect(parent, &QAction::toggled,
-                parent, &KToggleAction::slotToggled);
-    }
-
-    KToggleAction *const parent;
-    KGuiItem *checkedGuiItem = nullptr;
-};
+#include "ktoggleaction_p.h"
 
 KToggleAction::KToggleAction(QObject *parent)
-    : QAction(parent),
-      d(new Private(this))
+    : KToggleAction(*new KToggleActionPrivate(this), parent)
 {
+}
+
+KToggleAction::KToggleAction(KToggleActionPrivate &dd, QObject *parent)
+    : QAction(parent)
+    , d(&dd)
+{
+    Q_D(KToggleAction);
+
     d->init();
 }
 
 KToggleAction::KToggleAction(const QString &text, QObject *parent)
-    : QAction(parent),
-      d(new Private(this))
+    : QAction(parent)
+    , d(new KToggleActionPrivate(this))
 {
+    Q_D(KToggleAction);
+
     setText(text);
     d->init();
 }
 
 KToggleAction::KToggleAction(const QIcon &icon, const QString &text, QObject *parent)
-    : QAction(parent),
-      d(new Private(this))
+    : QAction(parent)
+    , d(new KToggleActionPrivate(this))
 {
+    Q_D(KToggleAction);
+
     setIcon(icon);
     setText(text);
     d->init();
 }
 
-KToggleAction::~KToggleAction()
-{
-    delete d;
-}
+KToggleAction::~KToggleAction() = default;
 
 void KToggleAction::setCheckedState(const KGuiItem &checkedItem)
 {
+    Q_D(KToggleAction);
+
     delete d->checkedGuiItem;
     d->checkedGuiItem = new KGuiItem(checkedItem);
 }
 
 void KToggleAction::slotToggled(bool)
 {
+    Q_D(KToggleAction);
+
     if (d->checkedGuiItem) {
         QString string = d->checkedGuiItem->text();
         d->checkedGuiItem->setText(text());
@@ -96,3 +83,4 @@ void KToggleAction::slotToggled(bool)
     }
 }
 
+#include "moc_ktoggleaction.cpp"
